// First some functions to use in the installation.

// Used only for debugging when execution needs to be
// slowed down to follow the output to the Java Console.
function delay(amount) {
   if( (debugOutput) && (amount > 0) )
   {   
      var time = new Date();
      var seconds = time.getSeconds();
      var startCount = 80;
      var newSeconds = 70;

      startCount = (seconds + amount ) % 60;
      time = new Date();
      newSeconds = time.getSeconds();
      while (newSeconds != startCount ) {
         time = new Date();
         newSeconds = time.getSeconds();
      }
   }
}

// Conditionally displays a message only when debugging.
function dbgIfMsg(condition, message) {
   if(debugOutput && condition)
      java.lang.System.out.println(message);
}

// Displays a message only when debugging.
function dbgMsg(message) {
   if(debugOutput)
      java.lang.System.out.println(message);
}

// Pops an alert window only when NOT installing in silent mode.
function cAlert(message) {
   if(!this.silent)
      alert(message);
}

// Checks OS and version information.
function checkSystemEnvironment() {
   var err = 0;

   if(debugOutput) {
      registry_vi = netscape.softupdate.Trigger.GetVersionInfo("InstantPalace");
      dbgIfMsg( (registry_vi == null ), "Warning: No registry info for InstantPalace node");
      if (registry_vi != null) {
         dbgIfMsg( (vi.compareTo(registry_vi) <= 0), 
                    "Warning: Version is no newer than previously installed version.");
      }
   }

   dbgMsg("The value of navigator.platform is: " + navigator.platform);           
//   if (navigator.platform != "Win32") {
//      err = -20; // wrong OS 
//      dbgMsg("Error: Wrong operating system!");
//      cAlert("Error: Wrong operating system: " + navigator.platform);
//      return err;
//   }
   return err;
}

// A wrapper for calling the AddSubcomponent() function.
function newSub(fName, jarFilePath, tgtVI, tgtFolder, tgtFilePath) {
   dbgMsg("Filename in newSub is: " + jarFilePath);
   var err = su.AddSubcomponent(fName,tgtVI,jarFilePath,tgtFolder,tgtFilePath,this.force);
   dbgIfMsg( (err != 0), "Error Adding SubComponent " + fName + "error value: " + err);
   if(err != 0) {
      newSubFailure = true;
   }
   delay(FileDelayTime);
}

// This prepares the specific files to be installed.
function setupFiles(su) {
   var err = 0;

   if (su == null) {
      dbgMsg("Error passing su to setupFiles: " + err);
      return -1;
   }

   err = su.StartInstall("InstantPalace",        // Package name
                         vi,
                         netscape.softupdate.SoftwareUpdate.FULL_INSTALL);
   if (err !=0) {
      dbgMsg("Error at startInstall: " + err);
      return err;
   }

   JClassFolder = su.GetFolder("Java Download");
   if (JClassFolder == null) {
      dbgMsg("ERROR GETTING FOLDER: Java Download");
      return -1;
   }

   //   Java Classes
   newSub("BaseJarFile", "CC_IP.jar", vi, JClassFolder, "CC_IP.jar");

   // If any subcomponent failed, the installation aborts here.
   if (newSubFailure) {
      dbgMsg("Error adding at least one subcomponent.");
      abortMe();
    }

   return 0;
}

// Handles catastrophic errors.
function abortMe(err) {
   if(!abortCalled) {
      dbgMsg("Install Aborted." + err);
      cAlert("Install Aborted." + err);
      su.AbortInstall();
      abortCalled = true;
   }
}
// End of functions.

// ===================== START ACTUAL INSTALLATION =========================
// 
// Global variable declarations
// 
var updateObjectName = "InstantPalace";
var versionMaj = 2;
var versionMin = 3;
var versionRel = 0;
var versionBld = 11;
var FileDelayTime = 0; // Number of seconds delay between subcomponents when debugging

var abortCalled   = false;
var newSubFailure = false;
var debugOutput   = true;  // Turns debugging output on/off

var vi = new netscape.softupdate.VersionInfo(versionMaj, versionMin, versionRel, versionBld);
    dbgIfMsg( (vi == null), "Warning: Unable to create the VersionInfo object.");
var su = new netscape.softupdate.SoftwareUpdate( this, updateObjectName );
    dbgIfMsg( (su == null), "Warning: Unable to create the SoftwareUpdate object.");

//-------------------------------------------------
// Here starts the main body of execution.
//-------------------------------------------------
java.lang.System.out.println("Starting script...");

var err = 0;
if ( (su != null) ) {
   dbgMsg("new SoftwareUpdate succeeded.");
   err = checkSystemEnvironment();
   if ( err == 0 ) {
      dbgMsg("checkSystemEnvirnoment succeeded.");
      err = setupFiles(su);
      if (err == 0) {
         dbgMsg("setupFiles succeeded.");
         err = su.FinalizeInstall();             // This actually copies all the files.
         if (err == 0) {
            cAlert("Install Successfully Completed: Relaunch the Navigator to enable the Instant Palace.");
         }
         else {
            dbgMsg("Error at FinalizeInstall: " + err);
            abortMe(err);
         } //FinalizeInstall
      }
      else {
         dbgMsg("Error at setupFiles: " + err);
         abortMe(err);
      } //setupFiles
   } 
   else {
      dbgMsg("Error at checkSystemEnvironment: " + err);
      abortMe(err);
   } //checkSystemEnvironment
}
